"pargpaRC" <-
function(lmom,zeta=1,lower=-1,upper=20,checklmom=TRUE) {

    para <- vector(mode="numeric", length=3)

    if(length(lmom$source) == 1 && lmom$source == "TLmoms") {
      if(lmom$trim != 0) {
        warning("Attribute of TL-moments is not trim=0--can not complete parameter estimation")
        return()
      }
    }

    if(length(lmom$L1) == 0) { # convert to named L-moments
      lmom <- lmorph(lmom)     # nondestructive conversion!
    }
    if(checklmom & ! are.lmom.valid(lmom)) {
       warning("B-type L-moments are invalid")
       return()
    } 


    L1 <- lmom$L1
    L2 <- lmom$L2
    T3 <- lmom$TAU3

    mr <- function(r,z,k) { (1 - (1-z)^(r+k))/(r+k) } 
   
    f <- function(x) { 
      mr1 <- mr(1,zeta,x) 
      mr2 <- mr(2,zeta,x)
      mr3 <- mr(3,zeta,x)
      tau3 <- (mr1 -  3*mr2  +  2*mr3)/(mr1 - mr2)
      #cat(c(mr1,mr2,mr3,tau3,T3,"\n"))
      return(abs(T3-tau3))
    }

    optim <- optimize(f,lower=lower,upper=upper)
    #str(optim)
    K <- optim$minimum
    mr1 <- mr(1,zeta,K) 
    mr2 <- mr(2,zeta,K)
    A <- L2/(mr1 - mr2)
    X <- L1 - A*mr1
    z <- list(type="gpa",
              para=c(X,A,K),
              zeta=zeta,
              source="pargpaRC",
              optim=optim)
    return(z)
}
